@@ -52,9 +52,9 @@ PythonDependencyMessage::PythonDependencyMessage(QWidget *parent, AbstractPython
                 }
             } else {
                 if (m_interface->featureName().isEmpty()) {
-                    doShowMessage(i18n("Everything is configured: %1", list.join(QStringLiteral(", "))), KMessageWidget::Positive);
+                    doShowMessage(i18n("Everything is configured:<br>%1", list.join(QStringLiteral(", "))), KMessageWidget::Positive);
                 } else {
-                    doShowMessage(i18n("%1 is configured: %2", m_interface->featureName(), list.join(QStringLiteral(", "))), KMessageWidget::Positive);
+                    doShowMessage(i18n("%1 is configured:<br>%2", m_interface->featureName(), list.join(QStringLiteral(", "))), KMessageWidget::Positive);
                 }
             }
         });
@@ -184,8 +184,10 @@ bool AbstractPythonInterface::checkPython(bool useVenv, bool calculateSize, bool
         QDir pluginDir(QStandardPaths::writableLocation(QStandardPaths::AppLocalDataLocation));
         if (!pluginDir.exists(pythonPath)) {
             // Setup venv
-            if (forceInstall && !setupVenv()) {
-                return false;
+            if (forceInstall) {
+                if (!setupVenv()) {
+                    return false;
+                }
             } else {
                 // Venv folder not found, disable
                 useVenv = false;
@@ -327,9 +329,12 @@ QString AbstractPythonInterface::locateScript(const QString &script)
     return path;
 }
 
-void AbstractPythonInterface::addDependency(const QString &pipname, const QString &purpose)
+void AbstractPythonInterface::addDependency(const QString &pipname, const QString &purpose, bool optional)
 {
     m_dependencies.insert(pipname, purpose);
+    if (optional) {
+        m_optionalDeps << pipname;
+    }
 }
 
 void AbstractPythonInterface::addScript(const QString &script)
@@ -363,12 +368,22 @@ void AbstractPythonInterface::checkDependencies(bool force, bool async)
     }
     // Force check, reset flag
     m_missing.clear();
+    m_optionalMissing.clear();
     const QString output = runPackageScript(QStringLiteral("--check"));
+    QStringList missingDeps = output.split(QStringLiteral("Missing: "));
+    QStringList outputMissing;
+    for (auto &m : missingDeps) {
+        outputMissing << m.simplified();
+    }
     QStringList messages;
     if (!output.isEmpty()) {
         // We have missing dependencies
         for (auto i : m_dependencies.keys()) {
-            if (output.contains(i)) {
+            if (outputMissing.contains(i)) {
+                if (m_optionalDeps.contains(i)) {
+                    m_optionalMissing << i;
+                    continue;
+                }
                 m_missing.append(i);
                 if (m_dependencies.value(i).isEmpty()) {
                     messages.append(xi18n("The <application>%1</application> python module is required.", i));
@@ -380,12 +395,12 @@ void AbstractPythonInterface::checkDependencies(bool force, bool async)
     }
     m_dependenciesChecked = true;
     if (messages.isEmpty()) {
-        Q_EMIT dependenciesAvailable();
         if (async) {
             checkVersionsConcurrently();
         } else {
             checkVersions(true);
         }
+        Q_EMIT dependenciesAvailable();
     } else {
         Q_EMIT dependenciesMissing(messages);
     }
@@ -491,7 +506,10 @@ void AbstractPythonInterface::checkVersions(bool signalOnResult)
             name = name.simplified().section(QLatin1Char(' '), 1, 1);
             QString version = raw.at(i + 1);
             version = version.simplified().section(QLatin1Char(' '), 0, 0);
-            versions.append(QString("%1 %2").arg(name, version));
+            if (version == QLatin1String("missing")) {
+                version = i18nc("@item:intext indicates a missing dependency", "missing (optional)");
+            }
+            versions.append(QString("<b>%1</b> %2").arg(name, version));
             if (m_versions->contains(name)) {
                 (*m_versions)[name.toLower()] = version;
             } else {
@@ -499,7 +517,6 @@ void AbstractPythonInterface::checkVersions(bool signalOnResult)
             }
         }
     }
-    qDebug() << "::: CHECKING DEPENDENCIES... VERSION FOUND: " << versions;
     if (signalOnResult) {
         Q_EMIT checkVersionsResult(versions);
     }
@@ -611,3 +628,8 @@ bool AbstractPythonInterface::installInProcess() const
 {
     return installInProgress;
 }
+
+bool AbstractPythonInterface::optionalDependencyAvailable(const QString &dependency) const
+{
+    return !m_optionalMissing.contains(dependency);
+}
